using Windows.Globalization.NumberFormatting;

using Microsoft.UI.Xaml;
using Microsoft.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    ///  
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region  - MainPage()

        /// <summary>
        /// 
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            Loaded                                                      += Page_Loaded;
            this.zoomModeComboBox.SelectionChanged                      += zoomModeComboBox_SelectionChanged;
            this.zoomFactorNumberBox.ValueChanged                       += zoomFactorNumberBox_ValueChanged;
            this.horizontalScrollModeComboBox.SelectionChanged          += horizontalScrollModeComboBox_SelectionChanged;
            this.verticalScrollModeComboBox.SelectionChanged            += verticalScrollModeComboBox_SelectionChanged;
            this.horizontalScrollBarVisibilityComboBox.SelectionChanged += horizontalScrollBarVisibilityComboBox_SelectionChanged;
            this.verticalScrollBarVisibilityComboBox.SelectionChanged   += verticalScrollBarVisibilityComboBox_SelectionChanged;

            this.zoomModeComboBox.SelectedIndex                      = 0;
            this.horizontalScrollModeComboBox.SelectedIndex          = 2;
            this.verticalScrollModeComboBox.SelectedIndex            = 2;
            this.horizontalScrollBarVisibilityComboBox.SelectedIndex = 0;
            this.verticalScrollBarVisibilityComboBox.SelectedIndex   = 0;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region  ε óϱ - Page_Loaded(sender, e)

        /// <summary>
        ///  ε óϱ
        /// </summary>
        /// <param name="sender">̺Ʈ ߻</param>
        /// <param name="e">̺Ʈ </param>
        private void Page_Loaded(object sender, RoutedEventArgs e)
        {
            this.scrollView.ZoomTo
            (
                1.0f,
                null,
                new ScrollingZoomOptions(ScrollingAnimationMode.Enabled, ScrollingSnapPointsMode.Ignore)
            );

            IncrementNumberRounder rounder = new IncrementNumberRounder
            {
                Increment         = 0.1,
                RoundingAlgorithm = RoundingAlgorithm.RoundHalfUp
            };

            DecimalFormatter formatter = new DecimalFormatter
            {
                IntegerDigits  = 2,
                FractionDigits = 1,
                NumberRounder  = rounder
            };

            this.zoomFactorNumberBox.NumberFormatter = formatter;

            Loaded -= Page_Loaded;
        }

        #endregion
        #region ZoomMode ޺ ڽ   óϱ - zoomModeComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// ZoomMode ޺ ڽ   óϱ
        /// </summary>
        /// <param name="sender">̺Ʈ ߻</param>
        /// <param name="e">̺Ʈ </param>
        private void zoomModeComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollView != null)
            {
                if(sender is ComboBox comboBox)
                {
                    this.scrollView.ZoomMode = (ScrollingZoomMode)comboBox.SelectedIndex;
                }
            }
        }

        #endregion
        #region ZoomFactor ѹ ڽ   óϱ - zoomFactorNumberBox_ValueChanged(sender, e)

        /// <summary>
        /// ZoomFactor ѹ ڽ   óϱ
        /// </summary>
        /// <param name="sender">̺Ʈ ߻</param>
        /// <param name="e">̺Ʈ </param>
        private void zoomFactorNumberBox_ValueChanged(NumberBox sender, NumberBoxValueChangedEventArgs e)
        {
            if(this.scrollView != null)
            {
                this.scrollView.ZoomTo((float)e.NewValue, null);
            }
        }

        #endregion
        #region Horizontal ScrollMode ޺ ڽ   óϱ - horizontalScrollModeComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// Horizontal ScrollMode ޺ ڽ   óϱ
        /// </summary>
        /// <param name="sender">̺Ʈ ߻</param>
        /// <param name="e">̺Ʈ </param>
        private void horizontalScrollModeComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollView != null)
            {
                if(sender is ComboBox comboBox)
                {
                    this.scrollView.HorizontalScrollMode = (ScrollingScrollMode)comboBox.SelectedIndex;
                }
            }
        }

        #endregion
        #region Vertical ScrollMode ޺ ڽ   óϱ - verticalScrollModeComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// Vertical ScrollMode ޺ ڽ   óϱ
        /// </summary>
        /// <param name="sender">̺Ʈ ߻</param>
        /// <param name="e">̺Ʈ </param>
        private void verticalScrollModeComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollView != null)
            {
                if(sender is ComboBox comboBox)
                {
                    this.scrollView.VerticalScrollMode = (ScrollingScrollMode)comboBox.SelectedIndex;
                }
            }
        }

        #endregion
        #region Horizontal ScrollBarVisibility ޺ ڽ   óϱ - horizontalScrollBarVisibilityComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// Horizontal ScrollBarVisibility ޺ ڽ   óϱ
        /// </summary>
        /// <param name="sender">̺Ʈ ߻</param>
        /// <param name="e">̺Ʈ </param>
        private void horizontalScrollBarVisibilityComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollView != null)
            {
                if(sender is ComboBox comboBox)
                {
                    this.scrollView.HorizontalScrollBarVisibility = (ScrollingScrollBarVisibility)comboBox.SelectedIndex;
                }
            }
        }

        #endregion
        #region Vertical ScrollBarVisibility ޺ ڽ   óϱ - verticalScrollBarVisibilityComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// Vertical ScrollBarVisibility ޺ ڽ   óϱ
        /// </summary>
        /// <param name="sender">̺Ʈ ߻</param>
        /// <param name="e">̺Ʈ </param>
        private void verticalScrollBarVisibilityComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollView != null)
            {
                if(sender is ComboBox comboBox)
                {
                    this.scrollView.VerticalScrollBarVisibility = (ScrollingScrollBarVisibility)comboBox.SelectedIndex;
                }
            }
        }

        #endregion
    }
}